#!/bin/bash
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

# Note: Also called from Debian
# Arguments:

# RPM
# $1 == 1 - install package
# $1 == 2 - upgrade package

# DEB
# $1 == configure - RPM post/posttrans

# "lve-utils POST TRANS STARTED"


rhel=$2
solo_marker=$3
_clshare=$4
cloudlinux_cron_file=$5
clwpos_redis_extension_installer=$6
clwpos_cleaner_cron=$7
clwpos_collect_information_cron=$8
add_clwpos_crons=$9
app_detector_cron_ver_file=${10}
crondir_dom_coll_file=${11}
force_collecting_domains_is_done=${12}
force_collecting_domains_cron_file=${13}
_clshare_crons=${14}
optpath=${15}
app_detector_cron_ver=${16}
wpos_req_cron_file=${17}
_clshare_wpos=${18}


# Setup Cloudlinux WPOS daemon
"$_clshare_wpos"/wpos_daemon_setup.py


# Install crons
echo "$(( RANDOM % 60 )) $(( RANDOM % 24 ))  * * * root /usr/bin/flock -n /var/run/cloudlinux_cldetect.cronlock /usr/bin/cldetect --update-license" >  "$cloudlinux_cron_file"
echo "$(( RANDOM % 60 )) $(( RANDOM % 24 ))  * * * root /usr/bin/flock -n /var/run/cloudlinux_summary.cronlock /usr/sbin/cloudlinux-summary --send --json &> /dev/null" >>  "$cloudlinux_cron_file"
echo "$(( RANDOM % 60 )) $(( RANDOM % 24 ))  * * * root /usr/bin/flock -n /var/run/cloudlinux_summary_rpm.cronlock /usr/sbin/cloudlinux-summary rpm-packages --send --json &> /dev/null" >>  "$cloudlinux_cron_file"
# LU-2603 send statistics on first boot
echo "@reboot root test -f /var/lve/.boot_statistics_sent || { /usr/bin/flock -n /var/run/cloudlinux_summary.cronlock /usr/sbin/cloudlinux-summary --send --json &> /dev/null && touch /var/lve/.boot_statistics_sent; }" >> "$cloudlinux_cron_file"

if [[ -f "$solo_marker" ]]; then
    nohup /usr/sbin/enable_redis_for_ea_php &> /dev/null &
    CLSHARE=$_clshare WPOS_REQ_CRON_FILE=$wpos_req_cron_file CLWPOS_REDIS_EXTENSION_INSTALLER=$clwpos_redis_extension_installer CLWPOS_CLEANER_CRON=$clwpos_cleaner_cron CLWPOS_COLLECT_INFORMATION_CRON=$clwpos_collect_information_cron sh "$add_clwpos_crons"
fi

# Regenerate info.json files
nohup /usr/sbin/clwpos_collect_information.py  &> /dev/null &

# Install LU-1751 cloudlinux_domains_collector monthly cron
arch=$(uname -i)
if [[ $arch == x86_64* ]]; then
  # all systems except CL6x32

  # LU-1903. Part 2. Cron file versioning mechanism
  # We are creating cron file only if absent or have old version
  CRON_CURRENT_VER="<None>"
  if [[ -f $app_detector_cron_ver_file ]]; then
      CRON_CURRENT_VER=`cat "$app_detector_cron_ver_file"`
  fi

  avd_cron_cmd='/usr/bin/cloudlinux_domains_collector | /opt/app-version-detector/app-version-detector-wrapper.sh --send-stats --scan-depth=2'

  if [[ ! -f "$crondir_dom_coll_file" || "$CRON_CURRENT_VER" != "$app_detector_cron_ver" ]]; then
      # versions differ, update cron
      DAY=$[ ( RANDOM % 27 ) + 1 ]
      cron_file_content="$(( RANDOM % 60 )) $(( RANDOM % 24 )) $DAY * * root /usr/bin/flock -n /var/run/cloudlinux_domains_collector.cronlock $avd_cron_cmd"

      echo "$cron_file_content" > "$crondir_dom_coll_file"
      echo "$app_detector_cron_ver" > "$app_detector_cron_ver_file"
  fi
  if [[ ! -f "$force_collecting_domains_is_done" && ! -f "$force_collecting_domains_cron_file" ]]; then
      # run the crontask in the next five days
      DAY=$(date -d 'now + '$(( RANDOM % 5 + 1 ))'days' +%d)
      cron_file_content="$(( RANDOM % 60 )) $(( RANDOM % 24 )) $DAY * * root /usr/bin/flock -n /var/run/cloudlinux_domains_collector.cronlock $avd_cron_cmd \
      && touch $force_collecting_domains_is_done && rm -f $force_collecting_domains_cron_file"

      echo "$cron_file_content" > "$force_collecting_domains_cron_file"
  fi
fi

if ! /usr/bin/cldetect --detect-cp | grep 'ISPManager' > /dev/null ; then
    if [[ ! -f $solo_marker ]]; then
        cp -f /usr/bin/lveutils-panel-cron /etc/cron.d/lveutils-panel-cron
        chmod 0644 /etc/cron.d/lveutils-panel-cron
    fi
fi

if [[ ! -f $solo_marker ]]; then
    ln -sf "$_clshare_crons"/cl_plus /etc/cron.d/cl_plus
fi

if [ -f /proc/lve/list ]; then
    /usr/sbin/processpaneluserspackages
fi
if [ -e "/etc/cron.d/lveutils-cpanel-cron" ]; then
    rm -f /etc/cron.d/lveutils-cpanel-cron
fi

if [[ ! -f $solo_marker ]]; then
    # Move `fs.proc_super_gid` and `fs.symlinkown_gid` to /etc/sysctl.d/90-cloudlinux.conf from /etc/sysctl.conf
    "$optpath"/bin/cl_sysctl migrate --parameter fs.proc_super_gid
    "$optpath"/bin/cl_sysctl migrate --parameter fs.symlinkown_gid

    # set securelinks gid if httpd gid != 48 (default)
    /usr/bin/cldetect --set-securelinks-gid > /dev/null

    # setup fs.proc_super_gid for few special users
    /usr/bin/cldetect --setup-supergids > /dev/null
fi

# run license check on install/update
/usr/bin/cldetect --update-license > /dev/null  2>&1

if [[ ! -f $solo_marker ]]; then
    # start services
    /sbin/service lve_namespaces restart > /dev/null 2>&1
    /sbin/service lvectl restart > /dev/null 2>&1
fi
# this is not needed on CL Solo, cause option just enables lve patches applying
# for apache/php/mysql
# LU-1654: set cloudlinux=yes parameter in /usr/local/directadmin/custombuild/options.conf
if [[ "DirectAdmin" == "$(/usr/bin/cldetect --detect-cp-nameonly)" ]]; then
    if [[ ! -f $solo_marker ]]; then
        /usr/local/directadmin/custombuild/build set cloudlinux yes
    else
        /usr/local/directadmin/custombuild/build set cloudlinux no
    fi
fi

# populate cache with current control panel name
/usr/bin/flock -n /var/run/cloudlinux_panel-detect.cronlock /usr/bin/package_reinstaller.py init

# Restart WPOS daemon
if [[ ! -f $solo_marker ]]; then
  /sbin/service clwpos_monitoring restart &> /dev/null
else
  /sbin/service clwpos_monitoring try-restart
fi

# Install WPOS hooks
"$_clshare_wpos"/wpos_hooks.py --install > /dev/null

# Add to cagefs:
# - clwpos-user utility
# - file 'controlpanelname' to allow user to detect control panel
if [ -f /usr/sbin/cagefsctl ]; then
    echo -e "/usr/bin/clwpos-user\n/var/cache/controlpanelname" | /usr/sbin/cagefsctl --wait-lock --update-list &> /dev/null &
fi

# "lve-utils POST TRANS FINISHED"
